@@ -4,21 +4,21 @@ import re
 
 
 def get_old_version():
-    with open("setup.cfg") as fp:
+    with open("pyproject.toml") as fp:
         content = fp.read()
-    match = re.search(r"^version = (\d+\.\d+\.\d+)$", content, flags=re.MULTILINE)
+    match = re.search(r'^version = "(\d+\.\d+\.\d+)"$', content, flags=re.MULTILINE)
     assert match
     return match.group(1)
 
 
-def replace_version(old_version, new_version):
-    print(f"updating setup.cfg version to {new_version}")
-    with open("setup.cfg") as fp:
+def replace_version(filename, formatstr, old_version, new_version):
+    print(f"updating {filename}")
+    with open(filename) as fp:
         content = fp.read()
-    old_str = f"version = {old_version}"
-    new_str = f"version = {new_version}"
+    old_str = formatstr.format(old_version)
+    new_str = formatstr.format(new_version)
     content = content.replace(old_str, new_str)
-    with open("setup.cfg", "w") as fp:
+    with open(filename, "w") as fp:
         fp.write(content)
 
 
@@ -32,7 +32,7 @@ def main():
     old_version = get_old_version()
     new_version = old_version + f".dev{args.number}"
 
-    replace_version(old_version, new_version)
+    replace_version("pyproject.toml", 'version = "{}"', old_version, new_version)
     print("done")
 
 
